from rest_framework.generics import ListCreateAPIView, RetrieveUpdateDestroyAPIView, ListAPIView
from rest_framework import permissions

from django.http import HttpResponse, JsonResponse
from django.views.decorators.csrf import csrf_exempt
from rest_framework.parsers import JSONParser

from reqman.apps.reqtool.models.suffix_req import Suffix
from reqman.apps.reqtool.rest_api.serializers.suffix_req import SuffixSerializer

from reqman.apps.permissions import IsOwnerOrReadOnly
from reqman.apps.reqtool.rest_api.services import fuseki

from rest_framework.response import Response
from rest_framework.views import APIView

from reqman.apps.reqtool.models.suffix_req import S_CHOICES, NUMBER_UNITS_CHOICES, TIME_UNITS_CHOICES, FLOW_CHOICES


class SuffixListAPIView(ListAPIView):
    """
    API view to retrieve list of posts or create new
    """
    permission_classes = [permissions.IsAuthenticatedOrReadOnly]
    serializer_class = SuffixSerializer
    #
    queryset = Suffix.objects.all()

    def get_queryset(self):
        group_pk = self.kwargs['boilerplate']
        #print(group_pk)
        queryset_suffix = Suffix.objects.filter(boilerplate_of_suffix = group_pk)
        return queryset_suffix

    #Custom actions when POST
    def perform_create(self, serializer):
        serializer.save()
        #print the data of the post
        #write_fuseki = fuseki.FusekiActions()
        #write_fuseki.write(serializer.data)

class SuffixDetailsAPIView(RetrieveUpdateDestroyAPIView):
    """
    API view to retrieve, update or delete post
    """
    permission_classes = [permissions.IsAuthenticatedOrReadOnly]

    serializer_class = SuffixSerializer
    
    def get_queryset(self):
        group_pk = self.kwargs['boilerplate']
        #print(group_pk)
        queryset_suffix = Suffix.objects.filter(boilerplate_of_suffix = group_pk)
        return queryset_suffix

    #Custom actions when PUT
    def perform_update(self, serializer):
        serializer.save()
        #print(self.new.changed_data)
        #instance = serializer.save()
        #write_fuseki = fuseki.FusekiActions()
        #write_fuseki.write(serializer.data)

    #Custom actions when DELETE
    def perform_destroy(self, instance):
        #print("deleted")
        instance.delete()


class SuffixChoicesViewSet(APIView):

    def get(self, request):
        response = Response(S_CHOICES)
        return response


class NumChoicesViewSet(APIView):

    def get(self, request):
        response = Response(NUMBER_UNITS_CHOICES)
        return response


class TimeChoicesViewSet(APIView):

    def get(self, request):
        response = Response(TIME_UNITS_CHOICES)
        return response


class FlowChoicesViewSet(APIView):

    def get(self, request):
        response = Response(FLOW_CHOICES)
        return response

